==> ckan-2.0.tar.gz: ckan-2.0/ckan/public/base/i18n/de.js <==
{
  "": {
    "domain": "ckan",
    "lang": "de",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Es trat ein Fehler auf"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Bist du sicher, dass du diese Aktion ausführen willst?"
  ],
  "Cancel": [
    null,
    "Abbrechen"
  ],
  "Confirm": [
    null,
    "Bestätigen"
  ],
  "Edit": [
    null,
    "Bearbeiten"
  ],
  "Failed to load data API information": [
    null,
    "Informationen zur Daten-API konnten nicht geladen werden"
  ],
  "Follow": [
    null,
    "Folgen"
  ],
  "Hide": [
    null,
    "Verstecken"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Eingabe ist zu kurz, muss mindestens ein Zeichen sein"
  ],
  "Loading...": [
    null,
    "Läd..."
  ],
  "No matches found": [
    null,
    "Keine Treffer"
  ],
  "Please Confirm Action": [
    null,
    "Bestätige bitte die Aktion"
  ],
  "Resource uploaded": [
    null,
    "Ressource hochgeladen"
  ],
  "Show more": [
    null,
    "Mehr anzeigen"
  ],
  "Start typing…": [
    null,
    "Gib etwas ein..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Dieses Formular hat ungespeicherte Änderungen"
  ],
  "There is no API data to load for this resource": [
    null,
    "Diese Ressource hat keine API-Daten zum Laden"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Upload konnte nicht autentifiziert werden"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Daten für hochgeladen Datei konnten nicht abgerufen werden"
  ],
  "Unable to upload file": [
    null,
    "Datei konnte nicht hochgeladen werden"
  ],
  "Unfollow": [
    null,
    "Entfolgen"
  ],
  "Upload a file": [
    null,
    "Datei hochladen"
  ],
  "show less": [
    null,
    "weniger anzeigen"
  ],
  "show more": [
    null,
    "mehr anzeigen"
  ]
}

==> ckan-2.1.tar.gz: ckan-2.1/ckan/public/base/i18n/de.js <==
{
  "": {
    "domain": "ckan",
    "lang": "de",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Es trat ein Fehler auf"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Bist du sicher, dass du diese Aktion ausführen willst?"
  ],
  "Cancel": [
    null,
    "Abbrechen"
  ],
  "Confirm": [
    null,
    "Bestätigen"
  ],
  "Edit": [
    null,
    "Bearbeiten"
  ],
  "Failed to load data API information": [
    null,
    "Informationen zur Daten-API konnten nicht geladen werden"
  ],
  "Follow": [
    null,
    "Folgen"
  ],
  "Hide": [
    null,
    "Verstecken"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Eingabe ist zu kurz, muss mindestens ein Zeichen sein"
  ],
  "Loading...": [
    null,
    "Lädt..."
  ],
  "No matches found": [
    null,
    "Keine Treffer"
  ],
  "Please Confirm Action": [
    null,
    "Bestätige bitte die Aktion"
  ],
  "Resource uploaded": [
    null,
    "Ressource hochgeladen"
  ],
  "Show more": [
    null,
    "Mehr anzeigen"
  ],
  "Start typing…": [
    null,
    "Gib etwas ein..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Dieses Formular hat ungespeicherte Änderungen"
  ],
  "There is no API data to load for this resource": [
    null,
    "Diese Ressource hat keine API-Daten zum Laden"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Upload konnte nicht autentifiziert werden"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Daten für hochgeladen Datei konnten nicht abgerufen werden"
  ],
  "Unable to upload file": [
    null,
    "Datei konnte nicht hochgeladen werden"
  ],
  "Unfollow": [
    null,
    "Entfolgen"
  ],
  "Upload a file": [
    null,
    "Datei hochladen"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Eine Datei wird hochgeladen. Soll das wirklich abgebrochen werden?"
  ],
  "show less": [
    null,
    "weniger anzeigen"
  ],
  "show more": [
    null,
    "mehr anzeigen"
  ]
}
